@@ -33,7 +33,7 @@ def main():
             help='Make server available externally.')
     parser.add_argument('-a', '--autoindex',
             action='store_false',
-            help='Enable autoindex files.')
+            help='Disable autoindex.')
     parser.add_argument('-d', '--hidden',
             action='store_false',
             help='Hide system files.')
